NAME = "bluer_sbc"

ICON = "🌀"

DESCRIPTION = f"{ICON} AI for single board computers."

VERSION = "8.163.1"

REPO_NAME = "bluer-sbc"

MARQUEE = "https://github.com/kamangir/blue-bracket/blob/main/images/helmet-3.jpg"

ALIAS = "@sbc"


def fullname() -> str:
    return f"{NAME}-{VERSION}"
