from bluer_options.env import load_config, load_env, get_env

load_config(__name__)
load_env(__name__)

BLUER_SBC_CAMERA_HI_RES = get_env("BLUER_SBC_CAMERA_HI_RES", True)
BLUER_SBC_CAMERA_WIDTH = get_env("BLUER_SBC_CAMERA_WIDTH", 728)
BLUER_SBC_CAMERA_HEIGHT = get_env("BLUER_SBC_CAMERA_HEIGHT", 600)
BLUER_SBC_CAMERA_ROTATION = get_env("BLUER_SBC_CAMERA_ROTATION", 0)
BLUER_SBC_CAMERA_KEEP_OPEN = get_env("BLUER_SBC_CAMERA_KEEP_OPEN", 0)

BLUER_SBC_DISPLAY_FULLSCREEN = get_env("BLUER_SBC_DISPLAY_FULLSCREEN", True)

BLUER_SBC_HARDWARE_KIND = get_env("BLUER_SBC_HARDWARE_KIND")

BLUER_SBC_SESSION_PLUGIN = get_env("BLUER_SBC_SESSION_PLUGIN")

BLUER_SBC_SESSION_IMAGER = get_env("BLUER_SBC_SESSION_IMAGER")
BLUER_SBC_SESSION_IMAGER_DIFF = get_env("BLUER_SBC_SESSION_IMAGER_DIFF", 0.1)
BLUER_SBC_SESSION_IMAGER_ENABLED = get_env("BLUER_SBC_SESSION_IMAGER_ENABLED", True)

BLUER_SBC_SESSION_MONITOR_ENABLED = get_env("BLUER_SBC_SESSION_MONITOR_ENABLED", True)

BLUER_SBC_SESSION_OBJECT_TAGS = get_env("BLUER_SBC_SESSION_OBJECT_TAGS")

BLUER_SBC_SESSION_OUTBOUND_QUEUE = get_env("BLUER_SBC_SESSION_OUTBOUND_QUEUE")

BLUER_SBC_SESSION_AUTO_UPLOAD = get_env("BLUER_SBC_SESSION_AUTO_UPLOAD", True)

BLUER_SBC_SESSION_IMAGER_PERIOD = get_env("BLUER_SBC_SESSION_IMAGER_PERIOD", 300)
BLUER_SBC_SESSION_MESSENGER_PERIOD = get_env("BLUER_SBC_SESSION_MESSENGER_PERIOD", 60)
BLUER_SBC_SESSION_REBOOT_PERIOD = get_env("BLUER_SBC_SESSION_REBOOT_PERIOD", 14400)
BLUER_SBC_SESSION_SCREEN_PERIOD = get_env("BLUER_SBC_SESSION_SCREEN_PERIOD", 4)
BLUER_SBC_SESSION_TEMPERATURE_PERIOD = get_env(
    "BLUER_SBC_SESSION_TEMPERATURE_PERIOD", 300
)

BLUER_SBC_ENV = get_env("BLUER_SBC_ENV")
